========
Strategy
========

This module provides the `FSMStrategy` enumeration which is used to define the strategy of the finite state machine.


.. autoclass:: litegram.fsm.strategy.FSMStrategy
    :members:
